package org.greenstone.gsdl3.core;
   
import org.w3c.dom.Node;                                                
/**
 * Module interface for all components/modules in greenstone.
 *
 * all components talk via a process method - in its simplest form,
 * it takes a String of XML, and returns a String of XML
 *
 * Java modules also implement a convenience process method -
 * uses DOM Nodes instead of Strings - avoids parsing the XML at each module
 */

public interface ModuleInterface {
 
  /**
   * Process an XML request - as a String
   *
   * @param xml_in the request to process
   * @return the response - contains any error messages
   * @see String
   */
    abstract public String process(String xml_in);

  /**
   * Process an XML request - as a DOM model node
   * the Node may be an ELement or a Document
   *
   * @param in the request to process
   * @return the response - contains any error messages
   * @see Node
   * @see Document
   * @see Element
   */
    abstract public Node process(Node xml_in);
    //abstract public XMLConverter process(XMLConverter out);
}    
                                                                           
